@@ -54,6 +54,9 @@ def _preprocess_data(data, mapping_rule, references, config):
     # data to str
     data = data.astype(str)
 
+    # remove duplicates
+    data = data.drop_duplicates()
+
     return data
 
 
@@ -245,25 +248,18 @@ def _materialize_mapping_rule_terms(results_df, mapping_rule, config):
     return results_df
 
 
-"""
 def _merge_data(data, parent_data, mapping_rule, join_condition):
     parent_data = parent_data.add_prefix('parent_')
     child_join_references, parent_join_references = get_references_in_join_condition(mapping_rule, join_condition)
     parent_join_references = ['parent_' + reference for reference in parent_join_references]
 
-    return data.merge(parent_data, how='inner', left_on=child_join_references, right_on=parent_join_references)
-"""
-
-
-def _merge_data(data, parent_data, mapping_rule, join_condition):
-    parent_data = parent_data.add_prefix('parent_')
-    child_join_references, parent_join_references = get_references_in_join_condition(mapping_rule, join_condition)
-    parent_join_references = ['parent_' + reference for reference in parent_join_references]
-
-    data = data.set_index(child_join_references, drop=False)
-    parent_data = parent_data.set_index(parent_join_references, drop=False)
-
-    return data.join(parent_data, how='inner')
+    # if there is only one join condition use join, otherwise use merge
+    if len(child_join_references) == 1:
+        data = data.set_index(child_join_references, drop=False)
+        parent_data = parent_data.set_index(parent_join_references, drop=False)
+        return data.join(parent_data, how='inner')
+    else:
+        return data.merge(parent_data, how='inner', left_on=child_join_references, right_on=parent_join_references)
 
 
 def _materialize_mapping_rule(mapping_rule, mappings_df, config, data=None, parent_join_references=set(), nest_level=0):
@@ -389,7 +385,7 @@ class Materializer:
         asserted_mapping_df = mappings_df.loc[mappings_df['triples_map_type'] == R2RML_TRIPLES_MAP_CLASS]
         self.mapping_partitions = [group for _, group in asserted_mapping_df.groupby(by='mapping_partition')]
 
-        remove_output_files(config, self.mappings_df)
+        prepare_output_files(config, self.mappings_df)
 
     def __str__(self):
         return str(self.mappings_df)
